<?php

namespace Drupal\face_login_gauth\Response;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Endroid\QrCode\ErrorCorrectionLevel;
use Endroid\QrCode\QrCode;
use Endroid\QrCode\Response\QrCodeResponse;

/**
 * Response which is returned as the QR code.
 *
 * @package Drupal\face_login_gauth\Response
 */
class QRImageResponse extends Response {

    /**
     * @var data
     */
    private $data;
    /**
     * @var logoWidth
     */
    private $logoWidth;

    /**
     * @var logoSize
     */
    private $logoSize;

    /**
     * @var logoMargin
     */
    private $logoMargin;

    /**
     * Recourse with generated image.
     *
     * @var resource
     */
    protected $image;

    /**
     * {@inheritdoc}
     */
    public function __construct($content, $status = 200, $headers = []) {
        parent::__construct(NULL, $status, $headers);
        $this->data = $content;
    }

    /**
     * {@inheritdoc}
     */
    public function prepare(Request $request) {
        return parent::prepare($request);
    }

    /**
     * {@inheritdoc}
     */
    public function sendHeaders() {
        $this->headers->set('content-type', 'image/jpeg');
        return parent::sendHeaders();
    }

    /**
     * {@inheritdoc}
     */
    public function sendContent() {
      $this->generateQRCode($this->data);
    }

    /**
     * Function generate QR code for the string or URL.
     *
     * @param string $string
     * @return boolean
     */
    private function generateQRCode(string $string = NULL) {
      $im = imagecreatefromstring($string);  // Generate Image.
            ob_start(); // Begin capturing the byte stream.
            imagejpeg($im);
            imagedestroy($im); // Clean up the image resource.
    }

}
